; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.







command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

;-| Special Motions |------------------------------------------------------



;AI Start----------------------------------------------------------------------------

 [Command]
name = "cpu1"
command = U, U, U, U
time = 0
[Command]
name = "cpu2"
command = U, U, U, D
time = 0
[Command]
name = "cpu3"
command = U, U, D, D
time = 0
[Command]
name = "cpu4"
command = U, D, D, D
time = 0
[Command]
name = "cpu5"
command = D, D, D, D
time = 0
[Command]
name = "cpu6"
command = D, D, D, U
time = 0
[Command]
name = "cpu7"
command = D, D, U, U
time = 0
[Command]
name = "cpu8"
command = D, U, U, U
time = 0
[Command]
name = "cpu9"
command = U, D, U, U
time = 0
[Command]
name = "cpu10"
command = U, U, D, U
time = 0
[Command]
name = "cpu11"
command = D, U, U, D
time = 0
[Command]
name = "cpu12"
command = U, D, D, U
time = 0
[Command]
name = "cpu13"
command = D, U, D, U
time = 0
[Command]
name = "cpu14"
command = U, D, U, D
time = 0
[Command]
name = "cpu15"
command = F, F, F, F
time = 0
[Command]
name = "cpu16"
command = B, B, B, B
time = 0
[Command]
name = "cpu17"
command = F, B, F, F
time = 0
[Command]
name = "cpu18"
command = F, F, B, F
time = 0
[Command]
name = "cpu19"
command = B, F, F, F
time = 0
[Command]
name = "cpu20"
command = F, F, F, B
time = 0
[Command]
name = "cpu21"
command = F, B, B, F
time = 0
[Command]
name = "cpu22"
command = B, F, F, B
time = 0
[Command]
name = "cpu23"
command = F, B, F, B
time = 0
[Command]
name = "cpu24"
command = B, F, B, F
time = 0
[Command]
name = "cpu25"
command = D, F, D, F
time = 0
[Command]
name = "cpu26"
command = D, B, D, B
time = 0
[Command]
name = "cpu27"
command = D, B, D, F
time = 0
[Command]
name = "cpu28"
command = D, F, D, B
time = 0
[Command]
name = "cpu29"
command = U, F, D, B
time = 0
[Command]
name = "cpu30"
command = U, B, D, F
time = 0
[Command]
name = "cpu31"
command = B, D, F, U
time = 0
[Command]
name = "cpu32"
command = F, D, B, U
time = 0
[Command]
name = "cpu33"
command = U, U, U, U
time = 0
[Command]
name = "cpu34"
command = U, U, U, D
time = 0
[Command]
name = "cpu35"
command = U, U, D, D
time = 0
[Command]
name = "cpu36"
command = U, D, D, D
time = 0
[Command]
name = "cpu37"
command = D, D, D, D
time = 0
[Command]
name = "cpu38"
command = D, D, D, U
time = 0
[Command]
name = "cpu39"
command = D, D, U, U
time = 0
[Command]
name = "cpu40"
command = D, U, U, U
time = 0
[Command]
name = "cpu41"
command = U, D, U, U
time = 0
[Command]
name = "cpu42"
command = U, U, D, U
time = 0
[Command]
name = "cpu43"
command = D, U, U, D
time = 0
[Command]
name = "cpu44"
command = U, D, D, U
time = 0
[Command]
name = "cpu45"
command = D, U, D, U
time = 0
[Command]
name = "cpu46"
command = U, D, U, D
time = 0
[Command]
name = "cpu47"
command = F, F, F, F
time = 0
[Command]
name = "cpu48"
command = B, B, B, B
time = 0
[Command]
name = "cpu49"
command = F, B, F, F
time = 0
[Command]
name = "cpu50"
command = F, F, B, F
time = 0
[Command]
name = "cpu51"
command = B, F, F, F
time = 0
[Command]
name = "cpu52"
command = F, F, F, B
time = 0
[Command]
name = "cpu53"
command = F, B, B, F
time = 0
[Command]
name = "cpu54"
command = B, F, F, B
time = 0
[Command]
name = "cpu55"
command = F, B, F, B
time = 0
[Command]
name = "cpu56"
command = B, F, B, F
time = 0
[Command]
name = "cpu57"
command = D, F, D, F
time = 0
[Command]
name = "cpu58"
command = D, B, D, B
time = 0
[Command]
name = "cpu59"
command = D, B, D, F
time = 0
[Command]
name = "cpu60"
command = D, F, D, B
time = 0
[Command]
name = "cpu61"
command = U, F, D, B
time = 0
[Command]
name = "cpu62"
command = U, B, D, F
time = 0
[Command]
name = "cpu63"
command = B, D, F, U
time = 0
[Command]
name = "cpu64"
command = F, D, B, U
time = 0

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[command]
name = "falconpunch1"
command = D,B,a
time = 15

[command]
name = "falconpunch2"
command = D,B,b
time = 15

[command]
name = "falconpunch3"
command = D,B,c
time = 15



[command]
name = "falconkick1"
command = D,F,a
time = 15

[command]
name = "falconkick2"
command = D,F,b
time = 15

[command]
name = "falconkick3"
command = D,F,c
time = 15
;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[command]
name = "UpA"
command = /$U,a
time = 15

[command]
name = "DownA"
command = /$D,a
time = 15

[command]
name = "DownB"
command = /$D,b
time = 15

[command]
name = "UpB"
command = /$U,b
time = 15

;-| Single Button |---------------------------------------------------------
[command]
name = "Attack1"
command = a
time = 15

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1



;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[statedef -1]

;-|Signal AI Routines|--------------------------------------------------------------------
[State -1, SetAI]
type = VarSet
triggerall = Alive && RoundState = 2
triggerall = IsHomeTeam
trigger1 = TeamSide = 2
trigger2 = MatchNo > 1
var(7) = 1

[State -1, CPUs]
type = VarSet
var(7) = 1
triggerall = Alive && RoundState = 2
triggerall = var(7) != 1
trigger1 = command = "cpu1"
trigger2 = command = "cpu2"
trigger3 = command = "cpu3"
trigger4 = command = "cpu4"
trigger5 = command = "cpu5"
trigger6 = command = "cpu6"
trigger7 = command = "cpu7"
trigger8 = command = "cpu8"
trigger9 = command = "cpu9"
trigger10 = command = "cpu10"
trigger11 = command = "cpu11"
trigger12 = command = "cpu12"
trigger13 = command = "cpu13"
trigger14 = command = "cpu14"
trigger15 = command = "cpu15"
trigger16 = command = "cpu16"
trigger17 = command = "cpu17"
trigger18 = command = "cpu18"
trigger19 = command = "cpu19"
trigger20 = command = "cpu20"
trigger21 = command = "cpu21"
trigger22 = command = "cpu22"
trigger23 = command = "cpu23"
trigger24 = command = "cpu24"
trigger25 = command = "cpu25"
trigger26 = command = "cpu26"
trigger27 = command = "cpu27"
trigger28 = command = "cpu28"
trigger29 = command = "cpu29"
trigger30 = command = "cpu30"
trigger31 = command = "cpu31"
trigger32 = command = "cpu32"
trigger33 = command = "cpu33"
trigger34 = command = "cpu34"
trigger35 = command = "cpu35"
trigger36 = command = "cpu36"
trigger37 = command = "cpu37"
trigger38 = command = "cpu38"
trigger39 = command = "cpu39"
trigger40 = command = "cpu40"
trigger41 = command = "cpu41"
trigger42 = command = "cpu42"
trigger43 = command = "cpu43"
trigger44 = command = "cpu44"
trigger45 = command = "cpu45"
trigger46 = command = "cpu46"
trigger47 = command = "cpu47"
trigger48 = command = "cpu48"
trigger49 = command = "cpu49"
trigger50 = command = "cpu50"
trigger51 = command = "cpu51"
trigger52 = command = "cpu52"
trigger53 = command = "cpu53"
trigger54 = command = "cpu54"
trigger55 = command = "cpu55"
trigger56 = command = "cpu56"
trigger57 = command = "cpu57"
trigger58 = command = "cpu58"
trigger59 = command = "cpu59"
trigger60 = command = "cpu60"
trigger61 = command = "cpu61"
trigger62 = command = "cpu62"
trigger63 = command = "cpu63"
trigger64 = command = "cpu64"

;Begin AI

;-------------------------------------------------------------------------------
;run
[State -1, Run]
type = ChangeState
value = 100
triggerall = var(7) = 1
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [10,200]
trigger1 = random = [0, 800]

[State -1, AI Punch 01]
type = ChangeState
value = 200
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,20]
trigger1 = random = [0, 600]

[State -1, AI Punch 02]
type = ChangeState
value = 210
triggerall = var(7) = 1
triggerall = stateno = 200
trigger1 = time >= 10
trigger1 = P2Movetype != A
trigger1 = statetype != A
trigger1 = random = [0, 600]

[State -1, AI Punch 03]
type = ChangeState
value = 211
triggerall = var(7) = 1
triggerall = stateno = 210
trigger1 = time >= 9
trigger1 = P2Movetype != A
trigger1 = statetype != A
trigger1 = random = [0, 600]

[State -1, AI Punch 04]
type = ChangeState
value = 212
triggerall = var(7) = 1
triggerall = stateno = 211
trigger1 = time >= 8
trigger1 = P2Movetype != A
trigger1 = statetype != A
trigger1 = random = [0, 500]

[State -1, AI Punch 05]
type = ChangeState
value = 213
triggerall = var(7) = 1
triggerall = stateno = 212
trigger1 = time >= 8
trigger1 = P2Movetype != A
trigger1 = statetype != A
trigger1 = random = [0, 500]

[State -1, AI Punch 06]
type = ChangeState
value = 214
triggerall = var(7) = 1
triggerall = stateno = 213
trigger1 = time >= 8
trigger1 = P2Movetype != A
trigger1 = statetype != A
trigger1 = random = [0, 600]

[State -1, AI Punch 07]
type = ChangeState
value = 240
triggerall = var(7) = 1
triggerall = stateno = 214
trigger1 = time >= 6
trigger1 = P2Movetype != A
trigger1 = statetype != A
trigger1 = random = [0, 400]

[State -1, AI Punch 08]
type = ChangeState
value = 250
triggerall = var(7) = 1
triggerall = stateno = 240
trigger1 = time >= 6
trigger1 = P2Movetype != A
trigger1 = statetype != A
trigger1 = random = [0, 300]

[State -1, AI Punch 09]
type = ChangeState
value = 580
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,30]
trigger1 = random = [0, 800]

[State -1, AI Punch 10]
type = ChangeState
value = 230
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,20]
trigger1 = random = [0, 400]

[State -1, AI Punch 11]
type = ChangeState
value = 610
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 500]

[State -1, AI Punch 12]
type = ChangeState
value = 620
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 300]

[State -1, AI Punch 13]
type = ChangeState
value = 700
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,30]
trigger1 = random = [0, 200]

[State -1, AI Punch 14]
type = ChangeState
value = 710
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 300]


[State -1, AI Punch Special 15]
type = ChangeState
value = 630
triggerall = var(7) = 1
triggerall = P2movetype != H
triggerall = power >= 1000
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,80]
trigger1 = random = [0, 999]

[State -1, AI Punch Special 16]
type = ChangeState
value = 720
triggerall = var(7) = 1
triggerall = P2movetype != H
triggerall = power >= 1000
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,100]
trigger1 = random = [0, 999]






[State -1, AI Punch Air 17]
type = ChangeState
value = 410
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 300]

[State -1, AI Punch Air 18]
type = ChangeState
value = 420
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 100]

[State -1, AI Punch Air 19]
type = ChangeState
value = 430
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 500]

[State -1, AI Punch Air 20]
type = ChangeState
value = 440
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 600]

[State -1, AI Punch Air 21]
type = ChangeState
value = 450
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 700]

[State -1, AI Punch Air 22]
type = ChangeState
value = 460
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = p2bodydist x = [0,40]
trigger1 = random = [0, 600]

[State -1, AI Punch 23]
type = ChangeState
value = 500
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,100]
trigger1 = random = [0, 100]

[State -1, AI Punch 24]
type = ChangeState
value = 250
triggerall = var(7) = 1
triggerall = P2movetype != H
trigger1 = P2Movetype != A
trigger1 = ctrl
trigger1 = statetype != A
trigger1 = p2bodydist x = [0,20]
trigger1 = random = [0, 300]

;-------------------------------------------------------------------------------

;falconpunch1
[State -1, falconpunch1]
type = ChangeState
value = 610
triggerall = command = "falconpunch1"
trigger1 = (statetype = s) && ctrl

;falconpunch1
[State -1, falconpunch2]
type = ChangeState
value = 620
triggerall = command = "falconpunch2"
trigger1 = (statetype = s) && ctrl

;falconpunch1
[State -1, falconpunch3]
type = ChangeState
value = 630
triggerall = command = "falconpunch3"
triggerall = power >= 1000
trigger1 = (statetype = s) && ctrl

;falconpunch1
[State -1, falconkick1]
type = ChangeState
value = 700
triggerall = command = "falconkick1"
trigger1 = (statetype = s) && ctrl

;falconpunch1
[State -1, falconkick2]
type = ChangeState
value = 710
triggerall = command = "falconkick2"
trigger1 = (statetype = s) && ctrl

;falconpunch1
[State -1, falconkick3]
type = ChangeState
value = 720
triggerall = command = "falconkick3"
triggerall = power >= 1000
trigger1 = (statetype = s) && ctrl

;UpA
[State -1, Air Up A]
type = ChangeState
value = 430
triggerall = command = "UpA"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = movecontact
trigger3 = stateno = 420
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact
trigger5 = stateno = 450
trigger5 = movecontact
trigger6 = stateno = 550
trigger6 = movecontact

;UpA
[State -1, Air Down A]
type = ChangeState
value = 440
triggerall = command = "DownA"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = movecontact
trigger3 = stateno = 420
trigger3 = movecontact
trigger4 = stateno = 430
trigger4 = movecontact
trigger5 = stateno = 450
trigger5 = movecontact
trigger6 = stateno = 550
trigger6 = movecontact

;UpA
[State -1, Air Down B]
type = ChangeState
value = 450
triggerall = command = "DownB"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = movecontact
trigger3 = stateno = 420
trigger3 = movecontact
trigger4 = stateno = 430
trigger4 = movecontact
trigger5 = stateno = 440
trigger5 = movecontact
trigger6 = stateno = 550
trigger6 = movecontact

;UpA
[State -1, Air Down B]
type = ChangeState
value = 460
triggerall = command = "UpB"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = movecontact
trigger3 = stateno = 420
trigger3 = movecontact
trigger4 = stateno = 430
trigger4 = movecontact
trigger5 = stateno = 440
trigger5 = movecontact
trigger6 = stateno = 550
trigger6 = movecontact



;===========================================================================
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Attack 1 A]
type = ChangeState
value = 200
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

[State -1,Attack 2 A]
type = ChangeState
value = 210
triggerall = stateno = 200
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = time >= 4

-----1-----

[State -1,Attack 3 A]
type = ChangeState
value = 211
triggerall = stateno = 210
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = time >= 7

[State -1,Attack 4 A]
type = ChangeState
value = 212
triggerall = stateno = 211
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = time >= 4

[State -1,Attack 5 A]
type = ChangeState
value = 213
triggerall = stateno = 212
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = time >= 4

[State -1,Attack 6 A]
type = ChangeState
value = 214
triggerall = stateno = 213
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = time >= 4
trigger2 = stateno = 230
trigger2 = movecontact
trigger3 = stateno = 240
trigger3 = movecontact
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Down Attack 1 A]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holdup"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 240
trigger3 = movecontact

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Attack 1 B]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 230
trigger3 = movecontact
trigger4 = stateno = 250
trigger4 = movecontact

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Down Attack 1 B]
type = ChangeState
value = 250
triggerall = command = "b"
triggerall = command != "holdup"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 230
trigger3 = movecontact
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Air Attack 1 A]
type = ChangeState
value = 410
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 420
trigger2 = movecontact
trigger3 = stateno = 430
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Air Attack 2 B]
type = ChangeState
value = 420
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 410
trigger2 = movecontact
trigger3 = stateno = 430
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Shoot Gun C]
type = ChangeState
value = 500
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 230
trigger4 = movecontact
trigger5 = stateno = 240
trigger5 = movecontact
trigger6 = stateno = 250
trigger6 = movecontact
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Shoot Gun Air C]
type = ChangeState
value = 550
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = A
trigger2 = stateno = 410
trigger2 = movecontact
trigger3 = stateno = 420
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact
trigger5 = stateno = 450
trigger5 = movecontact
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Down Attack 1 C]
type = ChangeState
value = 580
triggerall = command = "c"
triggerall = command != "holdup"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 230
trigger3 = movecontact
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------

